@@ -22,4 +22,7 @@ csvd = CSVD(sig.T, 0.01)
 sig_ = csvd.remove('auto',[-20,-10],3)
 plt.plot(fftshift(fft(sig[0,:])).T)
 plt.plot(fftshift(fft(sig_[:,0])).T)
-plt.show()
\ No newline at end of file
+plt.legend(['Orginal signal', 'Water-removed signal'])
+plt.savefig('example.jpg')
+plt.show()
+
